@@ -25,7 +25,7 @@
 
 /**
  * pango_ot_tag_from_script:
- * @script: A #PangoScript
+ * @script: A `PangoScript`
  *
  * Finds the OpenType script tag corresponding to @script.
  *
@@ -34,11 +34,11 @@
  * 'DFLT' script tag that is also defined as
  * %PANGO_OT_TAG_DEFAULT_SCRIPT.
  *
- * Note that multiple #PangoScript values may map to the same
+ * Note that multiple `PangoScript` values may map to the same
  * OpenType script tag.  In particular, %PANGO_SCRIPT_HIRAGANA
  * and %PANGO_SCRIPT_KATAKANA both map to the OT tag 'kana'.
  *
- * Return value: #PangoOTTag corresponding to @script or
+ * Return value: `PangoOTTag` corresponding to @script or
  * %PANGO_OT_TAG_DEFAULT_SCRIPT if none found.
  *
  * Since: 1.18
@@ -46,28 +46,37 @@
 PangoOTTag
 pango_ot_tag_from_script (PangoScript script)
 {
-  hb_tag_t tag1, tag2;
-  hb_ot_tags_from_script (hb_glib_script_to_script (script), &tag1, &tag2);
-  return (PangoOTTag) tag1;
+  unsigned int count = 1;
+  hb_tag_t tags[1];
+
+  hb_ot_tags_from_script_and_language ((hb_script_t) g_unicode_script_to_iso15924 ((GUnicodeScript) script),
+                                       HB_LANGUAGE_INVALID,
+                                       &count,
+                                       tags,
+                                       NULL, NULL);
+  if (count > 0)
+    return (PangoOTTag) tags[0];
+
+  return PANGO_OT_TAG_DEFAULT_SCRIPT;
 }
 
 /**
  * pango_ot_tag_to_script:
- * @script_tag: A #PangoOTTag OpenType script tag
+ * @script_tag: A `PangoOTTag` OpenType script tag
  *
- * Finds the #PangoScript corresponding to @script_tag.
+ * Finds the `PangoScript` corresponding to @script_tag.
  *
  * The 'DFLT' script tag is mapped to %PANGO_SCRIPT_COMMON.
  *
  * Note that an OpenType script tag may correspond to multiple
- * #PangoScript values.  In such cases, the #PangoScript value
+ * `PangoScript` values.  In such cases, the `PangoScript` value
  * with the smallest value is returned.
  * In particular, %PANGO_SCRIPT_HIRAGANA
  * and %PANGO_SCRIPT_KATAKANA both map to the OT tag 'kana'.
  * This function will return %PANGO_SCRIPT_HIRAGANA for
  * 'kana'.
  *
- * Return value: #PangoScript corresponding to @script_tag or
+ * Return value: `PangoScript` corresponding to @script_tag or
  * %PANGO_SCRIPT_UNKNOWN if none found.
  *
  * Since: 1.18
@@ -75,17 +84,17 @@ pango_ot_tag_from_script (PangoScript script)
 PangoScript
 pango_ot_tag_to_script (PangoOTTag script_tag)
 {
-  return (PangoScript) hb_glib_script_from_script (hb_ot_tag_to_script ((hb_tag_t) script_tag));
+  return (PangoScript) g_unicode_script_from_iso15924 (hb_ot_tag_to_script ((hb_tag_t) script_tag));
 }
 
 
 /**
  * pango_ot_tag_from_language:
- * @language: A #PangoLanguage, or %NULL
+ * @language: (nullable): A `PangoLanguage`
  *
  * Finds the OpenType language-system tag best describing @language.
  *
- * Return value: #PangoOTTag best matching @language or
+ * Return value: `PangoOTTag` best matching @language or
  * %PANGO_OT_TAG_DEFAULT_LANGUAGE if none found or if @language
  * is %NULL.
  *
@@ -94,17 +103,28 @@ pango_ot_tag_to_script (PangoOTTag script_tag)
 PangoOTTag
 pango_ot_tag_from_language (PangoLanguage *language)
 {
-  return (PangoOTTag) hb_ot_tag_from_language (hb_language_from_string (pango_language_to_string (language), -1));
+  unsigned int count = 1;
+  hb_tag_t tags[1];
+
+  hb_ot_tags_from_script_and_language (HB_SCRIPT_UNKNOWN,
+                                       hb_language_from_string (pango_language_to_string (language), -1),
+                                       NULL, NULL,
+                                       &count, tags);
+
+  if (count > 0)
+    return (PangoOTTag) tags[0];
+
+  return PANGO_OT_TAG_DEFAULT_LANGUAGE;
 }
 
 /**
  * pango_ot_tag_to_language:
- * @language_tag: A #PangoOTTag OpenType language-system tag
+ * @language_tag: A `PangoOTTag` OpenType language-system tag
  *
- * Finds a #PangoLanguage corresponding to @language_tag.
+ * Finds a `PangoLanguage` corresponding to @language_tag.
  *
- * Return value: #PangoLanguage best matching @language_tag or
- * #PangoLanguage corresponding to the string "xx" if none found.
+ * Return value: `PangoLanguage` best matching @language_tag or
+ * `PangoLanguage` corresponding to the string "xx" if none found.
  *
  * Since: 1.18
  **/
