@@ -6,6 +6,10 @@ char * diff_with_file (const char  *file,
                        gssize       len,
                        GError     **error);
 
+char * diff_bytes (GBytes  *b1,
+                   GBytes  *b2,
+                   GError **error);
+
 gboolean file_has_prefix (const char  *file,
                           const char  *str,
                           GError     **error);
@@ -19,13 +23,8 @@ void print_attributes (GSList        *attrs,
 void print_attr_list (PangoAttrList  *attrs,
                       GString        *string);
 
-PangoAttribute *
-attribute_from_string (const char *string);
-
-PangoAttrList *
-attributes_from_string (const char *string);
-
 const char *get_script_name (GUnicodeScript s);
 
+PangoFontMap *get_font_map_with_cantarell (void);
 
 #endif
